@@ -1,10 +1,10 @@
-use 5.16.0;
+use 5.20.0;
 use strict;
 use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.17_10';
+  our $VERSION = '0.17_11';
 
   use Zydeco
     authority => 'cpan:SMONFF',
@@ -18,6 +18,10 @@ package Art::World {
     #
     declare => [ 'Agent', 'Artwork', 'Collector', 'Theory', 'Idea'],
     version   => $VERSION;
+  if ( $] < 5.024 ) {
+    use feature "postderef";
+    no if ( $] >= 5.024 ), 'warnings' => 'experimental';
+  }
   use Carp;
   use utf8;
   use Config::Tiny;
@@ -358,8 +362,7 @@ package Art::World {
       }
 
       method generate_discourse( ArrayRef $buzz = [] ) {
-        for ( 0..2 ) { push $buzz->@*, Faker->new->company_buzzword_type1 };
-        p $buzz;
+        for ( 0 .. int rand( 3 )) { push $buzz->@*, Faker->new->company_buzzword_type1 };
         return join ' ', $buzz->@*;
       }
 
@@ -420,6 +423,10 @@ as somebody in the art world that buy but doesn't sale.
 
 If it's collectionable, it can go to a C<Collector> collection or in a C<Museum>.
 
+=head2 Event
+
+All the necessary attributes and methodes for having fun between Art::world's Agents.
+
 =head2 Exhibit
 
 Role for L<C<Places>|Art::World/"Place"> that display some  L<C<Artworks>|Art::World/"Artwork">.
@@ -548,8 +555,6 @@ C<Concept> is an abstract class that does the C<Abstraction> role.
 A special kind of Agent that I<can> select Artworks, define a thematic, setup
 everything in the space and write a catalog.
 
-=head2 Event
-
 =head2 Exhibition
 
 An C<Event> that is organised by a C<Curator>.
